@@ -20,6 +20,7 @@ use CPAN::Meta;
 use Command::Runner;
 use Config;
 use Cwd ();
+use Darwin::InitObjC;
 use File::Copy ();
 use File::Path ();
 use File::Spec;
@@ -365,18 +366,7 @@ sub cmd_install {
 sub install {
     my ($self, $master, $worker, $num) = @_;
 
-    if ($num > 1
-        && $^O eq "darwin"
-        && ($^X eq "/usr/bin/perl" || $^X eq "perl")
-        && !exists $ENV{OBJC_DISABLE_INITIALIZE_FORK_SAFETY}
-        && !$self->{_darwin_fixed}
-    ) {
-        my $lib = "/System/Library/Frameworks/Foundation.framework/Foundation";
-        $master->{logger}->log("dlopen $lib to initialize Objective-C APIs before fork(2)");
-        require DynaLoader;
-        DynaLoader::dl_load_file $lib;
-        $self->{_darwin_fixed} = 1;
-    }
+    Darwin::InitObjC::maybe_init();
 
     my @task = $master->get_task;
     Parallel::Pipes::App->run(
